=============================================
The Rubicon Java Developer and User community
=============================================

Rubicon Java is part of the `BeeWare suite`_. You can talk to the
community through:

* `@pybeeware on Twitter`_

* The `beeware/general`_ channel on Gitter.

Code of Conduct
---------------

The BeeWare community has a strict `Code of Conduct`_. All users and
developers are expected to adhere to this code.

If you have any concerns about this code of conduct, or you wish to report a
violation of this code, please contact the project founder `Russell Keith-Magee`_.

Contributing
------------

If you experience problems with Rubicon, `log them on GitHub`_. If you
want to contribute code, please `fork the code`_ and `submit a pull request`_.

.. _BeeWare suite: http://beeware.org
.. _Read The Docs: https://rubicon-java.readthedocs.io
.. _@pybeeware on Twitter: https://twitter.com/pybeeware
.. _beeware/general: https://gitter.im/beeware/general
.. _log them on Github: https://github.com/beeware/rubicon-java/issues
.. _fork the code: https://github.com/beeware/rubicon-java
.. _submit a pull request: https://github.com/beeware/rubicon-java/pulls

.. _Code of Conduct: http://beeware.org/contributing/index.html
.. _Russell Keith-Magee: mailto:russell@keith-magee.com
